@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/graphics/ObjectProxy.h"
+#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/graphics/ObjectProxy.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_QtHandles__ObjectProxy_t {
-    QByteArrayData data[9];
-    char stringdata0[83];
+    QByteArrayData data[6];
+    char stringdata0[59];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -39,15 +39,11 @@ QT_MOC_LITERAL(1, 23, 10), // "sendUpdate"
 QT_MOC_LITERAL(2, 34, 0), // ""
 QT_MOC_LITERAL(3, 35, 3), // "pId"
 QT_MOC_LITERAL(4, 39, 10), // "sendRedraw"
-QT_MOC_LITERAL(5, 50, 8), // "sendShow"
-QT_MOC_LITERAL(6, 59, 9), // "sendPrint"
-QT_MOC_LITERAL(7, 69, 8), // "file_cmd"
-QT_MOC_LITERAL(8, 78, 4) // "term"
+QT_MOC_LITERAL(5, 50, 8) // "sendShow"
 
     },
     "QtHandles::ObjectProxy\0sendUpdate\0\0"
-    "pId\0sendRedraw\0sendShow\0sendPrint\0"
-    "file_cmd\0term"
+    "pId\0sendRedraw\0sendShow"
 };
 #undef QT_MOC_LITERAL
 
@@ -57,24 +53,22 @@ static const uint qt_meta_data_QtHandles__ObjectProxy[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       4,   14, // methods
+       3,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       4,       // signalCount
+       3,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,   34,    2, 0x06 /* Public */,
-       4,    0,   37,    2, 0x06 /* Public */,
-       5,    0,   38,    2, 0x06 /* Public */,
-       6,    2,   39,    2, 0x06 /* Public */,
+       1,    1,   29,    2, 0x06 /* Public */,
+       4,    0,   32,    2, 0x06 /* Public */,
+       5,    0,   33,    2, 0x06 /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::Int,    3,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,    8,
 
        0        // eod
 };
@@ -88,7 +82,6 @@ void QtHandles::ObjectProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _
         case 0: _t->sendUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
         case 1: _t->sendRedraw(); break;
         case 2: _t->sendShow(); break;
-        case 3: _t->sendPrint((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -114,13 +107,6 @@ void QtHandles::ObjectProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _
                 return;
             }
         }
-        {
-            typedef void (ObjectProxy::*_t)(const QString & , const QString & );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ObjectProxy::sendPrint)) {
-                *result = 3;
-                return;
-            }
-        }
     }
 }
 
@@ -149,13 +135,13 @@ int QtHandles::ObjectProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 4)
+        if (_id < 3)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 4;
+        _id -= 3;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 4)
+        if (_id < 3)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 4;
+        _id -= 3;
     }
     return _id;
 }
@@ -178,12 +164,5 @@ void QtHandles::ObjectProxy::sendShow()
 {
     QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
 }
-
-// SIGNAL 3
-void QtHandles::ObjectProxy::sendPrint(const QString & _t1, const QString & _t2)
-{
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
-    QMetaObject::activate(this, &staticMetaObject, 3, _a);
-}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
