@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/qterminal/libqterminal/unix/Emulation.h"
+#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/qterminal/libqterminal/unix/Emulation.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_Emulation_t {
-    QByteArrayData data[43];
-    char stringdata0[465];
+    QByteArrayData data[46];
+    char stringdata0[543];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -49,49 +49,54 @@ QT_MOC_LITERAL(11, 94, 25), // "changeTabTextColorRequest"
 QT_MOC_LITERAL(12, 120, 5), // "color"
 QT_MOC_LITERAL(13, 126, 23), // "programUsesMouseChanged"
 QT_MOC_LITERAL(14, 150, 9), // "usesMouse"
-QT_MOC_LITERAL(15, 160, 13), // "outputChanged"
-QT_MOC_LITERAL(16, 174, 12), // "titleChanged"
-QT_MOC_LITERAL(17, 187, 5), // "title"
-QT_MOC_LITERAL(18, 193, 8), // "newTitle"
-QT_MOC_LITERAL(19, 202, 16), // "imageSizeChanged"
-QT_MOC_LITERAL(20, 219, 9), // "lineCount"
-QT_MOC_LITERAL(21, 229, 11), // "columnCount"
-QT_MOC_LITERAL(22, 241, 28), // "profileChangeCommandReceived"
-QT_MOC_LITERAL(23, 270, 4), // "text"
-QT_MOC_LITERAL(24, 275, 12), // "setImageSize"
-QT_MOC_LITERAL(25, 288, 5), // "lines"
-QT_MOC_LITERAL(26, 294, 7), // "columns"
-QT_MOC_LITERAL(27, 302, 8), // "sendText"
-QT_MOC_LITERAL(28, 311, 12), // "sendKeyEvent"
-QT_MOC_LITERAL(29, 324, 10), // "QKeyEvent*"
-QT_MOC_LITERAL(30, 335, 14), // "sendMouseEvent"
-QT_MOC_LITERAL(31, 350, 7), // "buttons"
-QT_MOC_LITERAL(32, 358, 6), // "column"
-QT_MOC_LITERAL(33, 365, 4), // "line"
-QT_MOC_LITERAL(34, 370, 9), // "eventType"
-QT_MOC_LITERAL(35, 380, 10), // "sendString"
-QT_MOC_LITERAL(36, 391, 6), // "string"
-QT_MOC_LITERAL(37, 398, 6), // "length"
-QT_MOC_LITERAL(38, 405, 11), // "receiveData"
-QT_MOC_LITERAL(39, 417, 6), // "buffer"
-QT_MOC_LITERAL(40, 424, 14), // "bufferedUpdate"
-QT_MOC_LITERAL(41, 439, 8), // "showBulk"
-QT_MOC_LITERAL(42, 448, 16) // "usesMouseChanged"
+QT_MOC_LITERAL(15, 160, 32), // "programBracketedPasteModeChanged"
+QT_MOC_LITERAL(16, 193, 18), // "bracketedPasteMode"
+QT_MOC_LITERAL(17, 212, 13), // "outputChanged"
+QT_MOC_LITERAL(18, 226, 12), // "titleChanged"
+QT_MOC_LITERAL(19, 239, 5), // "title"
+QT_MOC_LITERAL(20, 245, 8), // "newTitle"
+QT_MOC_LITERAL(21, 254, 16), // "imageSizeChanged"
+QT_MOC_LITERAL(22, 271, 9), // "lineCount"
+QT_MOC_LITERAL(23, 281, 11), // "columnCount"
+QT_MOC_LITERAL(24, 293, 28), // "profileChangeCommandReceived"
+QT_MOC_LITERAL(25, 322, 4), // "text"
+QT_MOC_LITERAL(26, 327, 12), // "setImageSize"
+QT_MOC_LITERAL(27, 340, 5), // "lines"
+QT_MOC_LITERAL(28, 346, 7), // "columns"
+QT_MOC_LITERAL(29, 354, 8), // "sendText"
+QT_MOC_LITERAL(30, 363, 12), // "sendKeyEvent"
+QT_MOC_LITERAL(31, 376, 10), // "QKeyEvent*"
+QT_MOC_LITERAL(32, 387, 14), // "sendMouseEvent"
+QT_MOC_LITERAL(33, 402, 7), // "buttons"
+QT_MOC_LITERAL(34, 410, 6), // "column"
+QT_MOC_LITERAL(35, 417, 4), // "line"
+QT_MOC_LITERAL(36, 422, 9), // "eventType"
+QT_MOC_LITERAL(37, 432, 10), // "sendString"
+QT_MOC_LITERAL(38, 443, 6), // "string"
+QT_MOC_LITERAL(39, 450, 6), // "length"
+QT_MOC_LITERAL(40, 457, 11), // "receiveData"
+QT_MOC_LITERAL(41, 469, 6), // "buffer"
+QT_MOC_LITERAL(42, 476, 14), // "bufferedUpdate"
+QT_MOC_LITERAL(43, 491, 8), // "showBulk"
+QT_MOC_LITERAL(44, 500, 16), // "usesMouseChanged"
+QT_MOC_LITERAL(45, 517, 25) // "bracketedPasteModeChanged"
 
     },
     "Emulation\0sendData\0\0const char*\0data\0"
     "len\0lockPtyRequest\0suspend\0useUtf8Request\0"
     "stateSet\0state\0changeTabTextColorRequest\0"
     "color\0programUsesMouseChanged\0usesMouse\0"
-    "outputChanged\0titleChanged\0title\0"
-    "newTitle\0imageSizeChanged\0lineCount\0"
-    "columnCount\0profileChangeCommandReceived\0"
-    "text\0setImageSize\0lines\0columns\0"
-    "sendText\0sendKeyEvent\0QKeyEvent*\0"
-    "sendMouseEvent\0buttons\0column\0line\0"
-    "eventType\0sendString\0string\0length\0"
-    "receiveData\0buffer\0bufferedUpdate\0"
-    "showBulk\0usesMouseChanged"
+    "programBracketedPasteModeChanged\0"
+    "bracketedPasteMode\0outputChanged\0"
+    "titleChanged\0title\0newTitle\0"
+    "imageSizeChanged\0lineCount\0columnCount\0"
+    "profileChangeCommandReceived\0text\0"
+    "setImageSize\0lines\0columns\0sendText\0"
+    "sendKeyEvent\0QKeyEvent*\0sendMouseEvent\0"
+    "buttons\0column\0line\0eventType\0sendString\0"
+    "string\0length\0receiveData\0buffer\0"
+    "bufferedUpdate\0showBulk\0usesMouseChanged\0"
+    "bracketedPasteModeChanged"
 };
 #undef QT_MOC_LITERAL
 
@@ -101,36 +106,38 @@ static const uint qt_meta_data_Emulation[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      20,   14, // methods
+      22,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-      10,       // signalCount
+      11,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    2,  114,    2, 0x06 /* Public */,
-       6,    1,  119,    2, 0x06 /* Public */,
-       8,    1,  122,    2, 0x06 /* Public */,
-       9,    1,  125,    2, 0x06 /* Public */,
-      11,    1,  128,    2, 0x06 /* Public */,
-      13,    1,  131,    2, 0x06 /* Public */,
-      15,    0,  134,    2, 0x06 /* Public */,
-      16,    2,  135,    2, 0x06 /* Public */,
-      19,    2,  140,    2, 0x06 /* Public */,
-      22,    1,  145,    2, 0x06 /* Public */,
+       1,    2,  124,    2, 0x06 /* Public */,
+       6,    1,  129,    2, 0x06 /* Public */,
+       8,    1,  132,    2, 0x06 /* Public */,
+       9,    1,  135,    2, 0x06 /* Public */,
+      11,    1,  138,    2, 0x06 /* Public */,
+      13,    1,  141,    2, 0x06 /* Public */,
+      15,    1,  144,    2, 0x06 /* Public */,
+      17,    0,  147,    2, 0x06 /* Public */,
+      18,    2,  148,    2, 0x06 /* Public */,
+      21,    2,  153,    2, 0x06 /* Public */,
+      24,    1,  158,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      24,    2,  148,    2, 0x0a /* Public */,
-      27,    1,  153,    2, 0x0a /* Public */,
-      28,    1,  156,    2, 0x0a /* Public */,
-      30,    4,  159,    2, 0x0a /* Public */,
-      35,    2,  168,    2, 0x0a /* Public */,
-      35,    1,  173,    2, 0x2a /* Public | MethodCloned */,
-      38,    2,  176,    2, 0x0a /* Public */,
-      40,    0,  181,    2, 0x09 /* Protected */,
-      41,    0,  182,    2, 0x08 /* Private */,
-      42,    1,  183,    2, 0x08 /* Private */,
+      26,    2,  161,    2, 0x0a /* Public */,
+      29,    1,  166,    2, 0x0a /* Public */,
+      30,    1,  169,    2, 0x0a /* Public */,
+      32,    4,  172,    2, 0x0a /* Public */,
+      37,    2,  181,    2, 0x0a /* Public */,
+      37,    1,  186,    2, 0x2a /* Public | MethodCloned */,
+      40,    2,  189,    2, 0x0a /* Public */,
+      42,    0,  194,    2, 0x09 /* Protected */,
+      43,    0,  195,    2, 0x08 /* Private */,
+      44,    1,  196,    2, 0x08 /* Private */,
+      45,    1,  199,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
@@ -139,22 +146,24 @@ static const uint qt_meta_data_Emulation[] = {
     QMetaType::Void, QMetaType::Int,   10,
     QMetaType::Void, QMetaType::Int,   12,
     QMetaType::Void, QMetaType::Bool,   14,
+    QMetaType::Void, QMetaType::Bool,   16,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Int, QMetaType::QString,   17,   18,
-    QMetaType::Void, QMetaType::Int, QMetaType::Int,   20,   21,
-    QMetaType::Void, QMetaType::QString,   23,
+    QMetaType::Void, QMetaType::Int, QMetaType::QString,   19,   20,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int,   22,   23,
+    QMetaType::Void, QMetaType::QString,   25,
 
  // slots: parameters
-    QMetaType::Void, QMetaType::Int, QMetaType::Int,   25,   26,
-    QMetaType::Void, QMetaType::QString,   23,
-    QMetaType::Void, 0x80000000 | 29,    2,
-    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   31,   32,   33,   34,
-    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,   36,   37,
-    QMetaType::Void, 0x80000000 | 3,   36,
-    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,   39,    5,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int,   27,   28,
+    QMetaType::Void, QMetaType::QString,   25,
+    QMetaType::Void, 0x80000000 | 31,    2,
+    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   33,   34,   35,   36,
+    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,   38,   39,
+    QMetaType::Void, 0x80000000 | 3,   38,
+    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,   41,    5,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void, QMetaType::Bool,   14,
+    QMetaType::Void, QMetaType::Bool,   16,
 
        0        // eod
 };
@@ -171,20 +180,22 @@ void Emulation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
         case 3: _t->stateSet((*reinterpret_cast< int(*)>(_a[1]))); break;
         case 4: _t->changeTabTextColorRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
         case 5: _t->programUsesMouseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 6: _t->outputChanged(); break;
-        case 7: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
-        case 8: _t->imageSizeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 9: _t->profileChangeCommandReceived((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 10: _t->setImageSize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 11: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 12: _t->sendKeyEvent((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
-        case 13: _t->sendMouseEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
-        case 14: _t->sendString((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 15: _t->sendString((*reinterpret_cast< const char*(*)>(_a[1]))); break;
-        case 16: _t->receiveData((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 17: _t->bufferedUpdate(); break;
-        case 18: _t->showBulk(); break;
-        case 19: _t->usesMouseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 6: _t->programBracketedPasteModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 7: _t->outputChanged(); break;
+        case 8: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
+        case 9: _t->imageSizeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 10: _t->profileChangeCommandReceived((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 11: _t->setImageSize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 12: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 13: _t->sendKeyEvent((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
+        case 14: _t->sendMouseEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
+        case 15: _t->sendString((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 16: _t->sendString((*reinterpret_cast< const char*(*)>(_a[1]))); break;
+        case 17: _t->receiveData((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 18: _t->bufferedUpdate(); break;
+        case 19: _t->showBulk(); break;
+        case 20: _t->usesMouseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 21: _t->bracketedPasteModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -231,31 +242,38 @@ void Emulation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, v
                 return;
             }
         }
+        {
+            typedef void (Emulation::*_t)(bool );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::programBracketedPasteModeChanged)) {
+                *result = 6;
+                return;
+            }
+        }
         {
             typedef void (Emulation::*_t)();
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::outputChanged)) {
-                *result = 6;
+                *result = 7;
                 return;
             }
         }
         {
             typedef void (Emulation::*_t)(int , const QString & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::titleChanged)) {
-                *result = 7;
+                *result = 8;
                 return;
             }
         }
         {
             typedef void (Emulation::*_t)(int , int );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::imageSizeChanged)) {
-                *result = 8;
+                *result = 9;
                 return;
             }
         }
         {
             typedef void (Emulation::*_t)(const QString & );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Emulation::profileChangeCommandReceived)) {
-                *result = 9;
+                *result = 10;
                 return;
             }
         }
@@ -287,13 +305,13 @@ int Emulation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 20)
+        if (_id < 22)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 20;
+        _id -= 22;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 20)
+        if (_id < 22)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 20;
+        _id -= 22;
     }
     return _id;
 }
@@ -341,30 +359,37 @@ void Emulation::programUsesMouseChanged(bool _t1)
 }
 
 // SIGNAL 6
-void Emulation::outputChanged()
+void Emulation::programBracketedPasteModeChanged(bool _t1)
 {
-    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 6, _a);
 }
 
 // SIGNAL 7
-void Emulation::titleChanged(int _t1, const QString & _t2)
+void Emulation::outputChanged()
 {
-    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
-    QMetaObject::activate(this, &staticMetaObject, 7, _a);
+    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
 }
 
 // SIGNAL 8
-void Emulation::imageSizeChanged(int _t1, int _t2)
+void Emulation::titleChanged(int _t1, const QString & _t2)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
     QMetaObject::activate(this, &staticMetaObject, 8, _a);
 }
 
 // SIGNAL 9
+void Emulation::imageSizeChanged(int _t1, int _t2)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
+    QMetaObject::activate(this, &staticMetaObject, 9, _a);
+}
+
+// SIGNAL 10
 void Emulation::profileChangeCommandReceived(const QString & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
-    QMetaObject::activate(this, &staticMetaObject, 9, _a);
+    QMetaObject::activate(this, &staticMetaObject, 10, _a);
 }
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
