@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/qterminal/libqterminal/unix/TerminalView.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/qterminal/libqterminal/unix/TerminalView.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_TerminalView_t {
-    QByteArrayData data[44];
-    char stringdata0[572];
+    QByteArrayData data[46];
+    char stringdata0[613];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -71,13 +71,15 @@ QT_MOC_LITERAL(33, 419, 15), // "outputSuspended"
 QT_MOC_LITERAL(34, 435, 9), // "suspended"
 QT_MOC_LITERAL(35, 445, 12), // "setUsesMouse"
 QT_MOC_LITERAL(36, 458, 9), // "usesMouse"
-QT_MOC_LITERAL(37, 468, 24), // "scrollBarPositionChanged"
-QT_MOC_LITERAL(38, 493, 5), // "value"
-QT_MOC_LITERAL(39, 499, 10), // "blinkEvent"
-QT_MOC_LITERAL(40, 510, 16), // "blinkCursorEvent"
-QT_MOC_LITERAL(41, 527, 10), // "enableBell"
-QT_MOC_LITERAL(42, 538, 14), // "swapColorTable"
-QT_MOC_LITERAL(43, 553, 18) // "tripleClickTimeout"
+QT_MOC_LITERAL(37, 468, 21), // "setBracketedPasteMode"
+QT_MOC_LITERAL(38, 490, 18), // "bracketedPasteMode"
+QT_MOC_LITERAL(39, 509, 24), // "scrollBarPositionChanged"
+QT_MOC_LITERAL(40, 534, 5), // "value"
+QT_MOC_LITERAL(41, 540, 10), // "blinkEvent"
+QT_MOC_LITERAL(42, 551, 16), // "blinkCursorEvent"
+QT_MOC_LITERAL(43, 568, 10), // "enableBell"
+QT_MOC_LITERAL(44, 579, 14), // "swapColorTable"
+QT_MOC_LITERAL(45, 594, 18) // "tripleClickTimeout"
 
     },
     "TerminalView\0interrupt_signal\0\0"
@@ -93,7 +95,8 @@ QT_MOC_LITERAL(43, 553, 18) // "tripleClickTimeout"
     "copyClipboard\0extra_interrupt\0"
     "pasteClipboard\0pasteSelection\0selectAll\0"
     "outputSuspended\0suspended\0setUsesMouse\0"
-    "usesMouse\0scrollBarPositionChanged\0"
+    "usesMouse\0setBracketedPasteMode\0"
+    "bracketedPasteMode\0scrollBarPositionChanged\0"
     "value\0blinkEvent\0blinkCursorEvent\0"
     "enableBell\0swapColorTable\0tripleClickTimeout"
 };
@@ -105,7 +108,7 @@ static const uint qt_meta_data_TerminalView[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      26,   14, // methods
+      28,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -113,34 +116,36 @@ static const uint qt_meta_data_TerminalView[] = {
       10,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    0,  144,    2, 0x06 /* Public */,
-       3,    1,  145,    2, 0x06 /* Public */,
-       6,    4,  148,    2, 0x06 /* Public */,
-      11,    2,  157,    2, 0x06 /* Public */,
-      14,    2,  162,    2, 0x06 /* Public */,
-      15,    3,  167,    2, 0x06 /* Public */,
-      19,    1,  174,    2, 0x06 /* Public */,
-      20,    1,  177,    2, 0x06 /* Public */,
-      22,    1,  180,    2, 0x06 /* Public */,
-      24,    1,  183,    2, 0x06 /* Public */,
+       1,    0,  154,    2, 0x06 /* Public */,
+       3,    1,  155,    2, 0x06 /* Public */,
+       6,    4,  158,    2, 0x06 /* Public */,
+      11,    2,  167,    2, 0x06 /* Public */,
+      14,    2,  172,    2, 0x06 /* Public */,
+      15,    3,  177,    2, 0x06 /* Public */,
+      19,    1,  184,    2, 0x06 /* Public */,
+      20,    1,  187,    2, 0x06 /* Public */,
+      22,    1,  190,    2, 0x06 /* Public */,
+      24,    1,  193,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      25,    0,  186,    2, 0x0a /* Public */,
-      26,    0,  187,    2, 0x0a /* Public */,
-      27,    0,  188,    2, 0x0a /* Public */,
-      28,    1,  189,    2, 0x0a /* Public */,
-      30,    0,  192,    2, 0x0a /* Public */,
-      31,    0,  193,    2, 0x0a /* Public */,
-      32,    0,  194,    2, 0x0a /* Public */,
-      33,    1,  195,    2, 0x0a /* Public */,
-      35,    1,  198,    2, 0x0a /* Public */,
-      36,    0,  201,    2, 0x0a /* Public */,
-      37,    1,  202,    2, 0x09 /* Protected */,
-      39,    0,  205,    2, 0x09 /* Protected */,
-      40,    0,  206,    2, 0x09 /* Protected */,
-      41,    0,  207,    2, 0x09 /* Protected */,
-      42,    0,  208,    2, 0x08 /* Private */,
-      43,    0,  209,    2, 0x08 /* Private */,
+      25,    0,  196,    2, 0x0a /* Public */,
+      26,    0,  197,    2, 0x0a /* Public */,
+      27,    0,  198,    2, 0x0a /* Public */,
+      28,    1,  199,    2, 0x0a /* Public */,
+      30,    0,  202,    2, 0x0a /* Public */,
+      31,    0,  203,    2, 0x0a /* Public */,
+      32,    0,  204,    2, 0x0a /* Public */,
+      33,    1,  205,    2, 0x0a /* Public */,
+      35,    1,  208,    2, 0x0a /* Public */,
+      36,    0,  211,    2, 0x0a /* Public */,
+      37,    1,  212,    2, 0x0a /* Public */,
+      38,    0,  215,    2, 0x0a /* Public */,
+      39,    1,  216,    2, 0x09 /* Protected */,
+      41,    0,  219,    2, 0x09 /* Protected */,
+      42,    0,  220,    2, 0x09 /* Protected */,
+      43,    0,  221,    2, 0x09 /* Protected */,
+      44,    0,  222,    2, 0x08 /* Private */,
+      45,    0,  223,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void,
@@ -165,7 +170,9 @@ static const uint qt_meta_data_TerminalView[] = {
     QMetaType::Void, QMetaType::Bool,   34,
     QMetaType::Void, QMetaType::Bool,   36,
     QMetaType::Bool,
-    QMetaType::Void, QMetaType::Int,   38,
+    QMetaType::Void, QMetaType::Bool,   38,
+    QMetaType::Bool,
+    QMetaType::Void, QMetaType::Int,   40,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -202,12 +209,15 @@ void TerminalView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id
         case 18: _t->setUsesMouse((*reinterpret_cast< bool(*)>(_a[1]))); break;
         case 19: { bool _r = _t->usesMouse();
             if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
-        case 20: _t->scrollBarPositionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 21: _t->blinkEvent(); break;
-        case 22: _t->blinkCursorEvent(); break;
-        case 23: _t->enableBell(); break;
-        case 24: _t->swapColorTable(); break;
-        case 25: _t->tripleClickTimeout(); break;
+        case 20: _t->setBracketedPasteMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 21: { bool _r = _t->bracketedPasteMode();
+            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
+        case 22: _t->scrollBarPositionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 23: _t->blinkEvent(); break;
+        case 24: _t->blinkCursorEvent(); break;
+        case 25: _t->enableBell(); break;
+        case 26: _t->swapColorTable(); break;
+        case 27: _t->tripleClickTimeout(); break;
         default: ;
         }
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
@@ -321,13 +331,13 @@ int TerminalView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 26)
+        if (_id < 28)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 26;
+        _id -= 28;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 26)
+        if (_id < 28)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 26;
+        _id -= 28;
     }
     return _id;
 }
