@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/m-editor/find-dialog.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/m-editor/find-dialog.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -25,7 +25,7 @@ QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__find_dialog_t {
     QByteArrayData data[14];
-    char stringdata0[212];
+    char stringdata0[205];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -35,27 +35,27 @@ struct qt_meta_stringdata_octave__find_dialog_t {
 static const qt_meta_stringdata_octave__find_dialog_t qt_meta_stringdata_octave__find_dialog = {
     {
 QT_MOC_LITERAL(0, 0, 19), // "octave::find_dialog"
-QT_MOC_LITERAL(1, 20, 25), // "handle_sel_search_changed"
-QT_MOC_LITERAL(2, 46, 0), // ""
-QT_MOC_LITERAL(3, 47, 24), // "handle_selection_changed"
-QT_MOC_LITERAL(4, 72, 12), // "has_selected"
-QT_MOC_LITERAL(5, 85, 30), // "handle_backward_search_changed"
-QT_MOC_LITERAL(6, 116, 26), // "handle_search_text_changed"
-QT_MOC_LITERAL(7, 143, 15), // "new_search_text"
-QT_MOC_LITERAL(8, 159, 4), // "find"
-QT_MOC_LITERAL(9, 164, 7), // "forward"
-QT_MOC_LITERAL(10, 172, 9), // "find_next"
-QT_MOC_LITERAL(11, 182, 9), // "find_prev"
-QT_MOC_LITERAL(12, 192, 7), // "replace"
-QT_MOC_LITERAL(13, 200, 11) // "replace_all"
+QT_MOC_LITERAL(1, 20, 9), // "find_next"
+QT_MOC_LITERAL(2, 30, 0), // ""
+QT_MOC_LITERAL(3, 31, 9), // "find_prev"
+QT_MOC_LITERAL(4, 41, 16), // "update_edit_area"
+QT_MOC_LITERAL(5, 58, 18), // "octave_qscintilla*"
+QT_MOC_LITERAL(6, 77, 25), // "handle_sel_search_changed"
+QT_MOC_LITERAL(7, 103, 24), // "handle_selection_changed"
+QT_MOC_LITERAL(8, 128, 12), // "has_selected"
+QT_MOC_LITERAL(9, 141, 30), // "handle_backward_search_changed"
+QT_MOC_LITERAL(10, 172, 4), // "find"
+QT_MOC_LITERAL(11, 177, 7), // "forward"
+QT_MOC_LITERAL(12, 185, 7), // "replace"
+QT_MOC_LITERAL(13, 193, 11) // "replace_all"
 
     },
-    "octave::find_dialog\0handle_sel_search_changed\0"
-    "\0handle_selection_changed\0has_selected\0"
-    "handle_backward_search_changed\0"
-    "handle_search_text_changed\0new_search_text\0"
-    "find\0forward\0find_next\0find_prev\0"
-    "replace\0replace_all"
+    "octave::find_dialog\0find_next\0\0find_prev\0"
+    "update_edit_area\0octave_qscintilla*\0"
+    "handle_sel_search_changed\0"
+    "handle_selection_changed\0has_selected\0"
+    "handle_backward_search_changed\0find\0"
+    "forward\0replace\0replace_all"
 };
 #undef QT_MOC_LITERAL
 
@@ -73,25 +73,25 @@ static const uint qt_meta_data_octave__find_dialog[] = {
        0,       // signalCount
 
  // slots: name, argc, parameters, tag, flags
-       1,    1,   64,    2, 0x08 /* Private */,
-       3,    1,   67,    2, 0x08 /* Private */,
-       5,    1,   70,    2, 0x08 /* Private */,
-       6,    1,   73,    2, 0x08 /* Private */,
-       8,    1,   76,    2, 0x08 /* Private */,
-       8,    0,   79,    2, 0x28 /* Private | MethodCloned */,
-      10,    0,   80,    2, 0x08 /* Private */,
-      11,    0,   81,    2, 0x08 /* Private */,
+       1,    0,   64,    2, 0x0a /* Public */,
+       3,    0,   65,    2, 0x0a /* Public */,
+       4,    1,   66,    2, 0x0a /* Public */,
+       6,    1,   69,    2, 0x08 /* Private */,
+       7,    1,   72,    2, 0x08 /* Private */,
+       9,    1,   75,    2, 0x08 /* Private */,
+      10,    1,   78,    2, 0x08 /* Private */,
+      10,    0,   81,    2, 0x28 /* Private | MethodCloned */,
       12,    0,   82,    2, 0x08 /* Private */,
       13,    0,   83,    2, 0x08 /* Private */,
 
  // slots: parameters
-    QMetaType::Void, QMetaType::Int,    2,
-    QMetaType::Void, QMetaType::Bool,    4,
-    QMetaType::Void, QMetaType::Int,    2,
-    QMetaType::Void, QMetaType::QString,    7,
-    QMetaType::Void, QMetaType::Bool,    9,
     QMetaType::Void,
     QMetaType::Void,
+    QMetaType::Void, 0x80000000 | 5,    2,
+    QMetaType::Void, QMetaType::Int,    2,
+    QMetaType::Void, QMetaType::Bool,    8,
+    QMetaType::Void, QMetaType::Int,    2,
+    QMetaType::Void, QMetaType::Bool,   11,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
@@ -105,18 +105,29 @@ void octave::find_dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         find_dialog *_t = static_cast<find_dialog *>(_o);
         Q_UNUSED(_t)
         switch (_id) {
-        case 0: _t->handle_sel_search_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 1: _t->handle_selection_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 2: _t->handle_backward_search_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 3: _t->handle_search_text_changed((*reinterpret_cast< QString(*)>(_a[1]))); break;
-        case 4: _t->find((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 5: _t->find(); break;
-        case 6: _t->find_next(); break;
-        case 7: _t->find_prev(); break;
+        case 0: _t->find_next(); break;
+        case 1: _t->find_prev(); break;
+        case 2: _t->update_edit_area((*reinterpret_cast< octave_qscintilla*(*)>(_a[1]))); break;
+        case 3: _t->handle_sel_search_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 4: _t->handle_selection_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 5: _t->handle_backward_search_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
+        case 6: _t->find((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 7: _t->find(); break;
         case 8: _t->replace(); break;
         case 9: _t->replace_all(); break;
         default: ;
         }
+    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        switch (_id) {
+        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
+        case 2:
+            switch (*reinterpret_cast<int*>(_a[1])) {
+            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
+            case 0:
+                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< octave_qscintilla* >(); break;
+            }
+            break;
+        }
     }
 }
 
@@ -150,7 +161,7 @@ int octave::find_dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         _id -= 10;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
         if (_id < 10)
-            *reinterpret_cast<int*>(_a[0]) = -1;
+            qt_static_metacall(this, _c, _id, _a);
         _id -= 10;
     }
     return _id;
