@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/m-editor/octave-qscintilla.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/m-editor/octave-qscintilla.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__octave_qscintilla_t {
-    QByteArrayData data[20];
-    char stringdata0[408];
+    QByteArrayData data[30];
+    char stringdata0[591];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -45,15 +45,25 @@ QT_MOC_LITERAL(7, 143, 13), // "status_update"
 QT_MOC_LITERAL(8, 157, 15), // "show_doc_signal"
 QT_MOC_LITERAL(9, 173, 35), // "context_menu_break_condition_..."
 QT_MOC_LITERAL(10, 209, 23), // "context_menu_break_once"
-QT_MOC_LITERAL(11, 233, 16), // "contextmenu_help"
-QT_MOC_LITERAL(12, 250, 15), // "contextmenu_doc"
-QT_MOC_LITERAL(13, 266, 20), // "contextmenu_help_doc"
-QT_MOC_LITERAL(14, 287, 16), // "contextmenu_edit"
-QT_MOC_LITERAL(15, 304, 15), // "contextmenu_run"
-QT_MOC_LITERAL(16, 320, 27), // "contextmenu_break_condition"
-QT_MOC_LITERAL(17, 348, 22), // "contextmenu_break_once"
-QT_MOC_LITERAL(18, 371, 12), // "text_changed"
-QT_MOC_LITERAL(19, 384, 23) // "cursor_position_changed"
+QT_MOC_LITERAL(11, 233, 28), // "ctx_menu_run_finished_signal"
+QT_MOC_LITERAL(12, 262, 15), // "QTemporaryFile*"
+QT_MOC_LITERAL(13, 278, 34), // "focus_console_after_command_s..."
+QT_MOC_LITERAL(14, 313, 17), // "interpreter_event"
+QT_MOC_LITERAL(15, 331, 12), // "fcn_callback"
+QT_MOC_LITERAL(16, 344, 3), // "fcn"
+QT_MOC_LITERAL(17, 348, 13), // "meth_callback"
+QT_MOC_LITERAL(18, 362, 4), // "meth"
+QT_MOC_LITERAL(19, 367, 21), // "ctx_menu_run_finished"
+QT_MOC_LITERAL(20, 389, 16), // "contextmenu_help"
+QT_MOC_LITERAL(21, 406, 15), // "contextmenu_doc"
+QT_MOC_LITERAL(22, 422, 20), // "contextmenu_help_doc"
+QT_MOC_LITERAL(23, 443, 16), // "contextmenu_edit"
+QT_MOC_LITERAL(24, 460, 15), // "contextmenu_run"
+QT_MOC_LITERAL(25, 476, 26), // "contextmenu_run_temp_error"
+QT_MOC_LITERAL(26, 503, 27), // "contextmenu_break_condition"
+QT_MOC_LITERAL(27, 531, 22), // "contextmenu_break_once"
+QT_MOC_LITERAL(28, 554, 12), // "text_changed"
+QT_MOC_LITERAL(29, 567, 23) // "cursor_position_changed"
 
     },
     "octave::octave_qscintilla\0"
@@ -62,9 +72,14 @@ QT_MOC_LITERAL(19, 384, 23) // "cursor_position_changed"
     "context_menu_edit_signal\0qsci_has_focus_signal\0"
     "status_update\0show_doc_signal\0"
     "context_menu_break_condition_signal\0"
-    "context_menu_break_once\0contextmenu_help\0"
-    "contextmenu_doc\0contextmenu_help_doc\0"
-    "contextmenu_edit\0contextmenu_run\0"
+    "context_menu_break_once\0"
+    "ctx_menu_run_finished_signal\0"
+    "QTemporaryFile*\0focus_console_after_command_signal\0"
+    "interpreter_event\0fcn_callback\0fcn\0"
+    "meth_callback\0meth\0ctx_menu_run_finished\0"
+    "contextmenu_help\0contextmenu_doc\0"
+    "contextmenu_help_doc\0contextmenu_edit\0"
+    "contextmenu_run\0contextmenu_run_temp_error\0"
     "contextmenu_break_condition\0"
     "contextmenu_break_once\0text_changed\0"
     "cursor_position_changed"
@@ -77,33 +92,39 @@ static const uint qt_meta_data_octave__octave_qscintilla[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      17,   14, // methods
+      23,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       8,       // signalCount
+      12,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,   99,    2, 0x06 /* Public */,
-       3,    1,  102,    2, 0x06 /* Public */,
-       5,    1,  105,    2, 0x06 /* Public */,
-       6,    1,  108,    2, 0x06 /* Public */,
-       7,    2,  111,    2, 0x06 /* Public */,
-       8,    1,  116,    2, 0x06 /* Public */,
-       9,    1,  119,    2, 0x06 /* Public */,
-      10,    1,  122,    2, 0x06 /* Public */,
+       1,    1,  129,    2, 0x06 /* Public */,
+       3,    1,  132,    2, 0x06 /* Public */,
+       5,    1,  135,    2, 0x06 /* Public */,
+       6,    1,  138,    2, 0x06 /* Public */,
+       7,    2,  141,    2, 0x06 /* Public */,
+       8,    1,  146,    2, 0x06 /* Public */,
+       9,    1,  149,    2, 0x06 /* Public */,
+      10,    1,  152,    2, 0x06 /* Public */,
+      11,    6,  155,    2, 0x06 /* Public */,
+      13,    0,  168,    2, 0x06 /* Public */,
+      14,    1,  169,    2, 0x06 /* Public */,
+      14,    1,  172,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      11,    1,  125,    2, 0x08 /* Private */,
-      12,    1,  128,    2, 0x08 /* Private */,
-      13,    1,  131,    2, 0x08 /* Private */,
-      14,    1,  134,    2, 0x08 /* Private */,
-      15,    1,  137,    2, 0x08 /* Private */,
-      16,    1,  140,    2, 0x08 /* Private */,
-      17,    1,  143,    2, 0x08 /* Private */,
-      18,    0,  146,    2, 0x08 /* Private */,
-      19,    2,  147,    2, 0x08 /* Private */,
+      19,    6,  175,    2, 0x08 /* Private */,
+      20,    1,  188,    2, 0x08 /* Private */,
+      21,    1,  191,    2, 0x08 /* Private */,
+      22,    1,  194,    2, 0x08 /* Private */,
+      23,    1,  197,    2, 0x08 /* Private */,
+      24,    1,  200,    2, 0x08 /* Private */,
+      25,    0,  203,    2, 0x08 /* Private */,
+      26,    1,  204,    2, 0x08 /* Private */,
+      27,    1,  207,    2, 0x08 /* Private */,
+      28,    0,  210,    2, 0x08 /* Private */,
+      29,    2,  211,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    2,
@@ -114,13 +135,19 @@ static const uint qt_meta_data_octave__octave_qscintilla[] = {
     QMetaType::Void, QMetaType::QString,    2,
     QMetaType::Void, QMetaType::Int,    2,
     QMetaType::Void, QMetaType::Int,    2,
+    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 12, 0x80000000 | 12, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
+    QMetaType::Void,
+    QMetaType::Void, 0x80000000 | 15,   16,
+    QMetaType::Void, 0x80000000 | 17,   18,
 
  // slots: parameters
+    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 12, 0x80000000 | 12, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void,
     QMetaType::Void, QMetaType::Bool,    2,
     QMetaType::Void, QMetaType::QPoint,    2,
     QMetaType::Void,
@@ -143,15 +170,21 @@ void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Cal
         case 5: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 6: _t->context_menu_break_condition_signal((*reinterpret_cast< int(*)>(_a[1]))); break;
         case 7: _t->context_menu_break_once((*reinterpret_cast< int(*)>(_a[1]))); break;
-        case 8: _t->contextmenu_help((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 9: _t->contextmenu_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 10: _t->contextmenu_help_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 11: _t->contextmenu_edit((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 12: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 13: _t->contextmenu_break_condition((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 14: _t->contextmenu_break_once((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 15: _t->text_changed(); break;
-        case 16: _t->cursor_position_changed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 8: _t->ctx_menu_run_finished_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[3])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
+        case 9: _t->focus_console_after_command_signal(); break;
+        case 10: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
+        case 11: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
+        case 12: _t->ctx_menu_run_finished((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[3])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
+        case 13: _t->contextmenu_help((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 14: _t->contextmenu_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 15: _t->contextmenu_help_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 16: _t->contextmenu_edit((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 17: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 18: _t->contextmenu_run_temp_error(); break;
+        case 19: _t->contextmenu_break_condition((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 20: _t->contextmenu_break_once((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 21: _t->text_changed(); break;
+        case 22: _t->cursor_position_changed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -212,6 +245,34 @@ void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Cal
                 return;
             }
         }
+        {
+            typedef void (octave_qscintilla::*_t)(bool , int , QTemporaryFile * , QTemporaryFile * , bool , bool );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::ctx_menu_run_finished_signal)) {
+                *result = 8;
+                return;
+            }
+        }
+        {
+            typedef void (octave_qscintilla::*_t)();
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::focus_console_after_command_signal)) {
+                *result = 9;
+                return;
+            }
+        }
+        {
+            typedef void (octave_qscintilla::*_t)(const fcn_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::interpreter_event)) {
+                *result = 10;
+                return;
+            }
+        }
+        {
+            typedef void (octave_qscintilla::*_t)(const meth_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::interpreter_event)) {
+                *result = 11;
+                return;
+            }
+        }
     }
 }
 
@@ -240,13 +301,13 @@ int octave::octave_qscintilla::qt_metacall(QMetaObject::Call _c, int _id, void *
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 17)
+        if (_id < 23)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 17;
+        _id -= 23;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 17)
+        if (_id < 23)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 17;
+        _id -= 23;
     }
     return _id;
 }
@@ -306,5 +367,32 @@ void octave::octave_qscintilla::context_menu_break_once(int _t1)
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 7, _a);
 }
+
+// SIGNAL 8
+void octave::octave_qscintilla::ctx_menu_run_finished_signal(bool _t1, int _t2, QTemporaryFile * _t3, QTemporaryFile * _t4, bool _t5, bool _t6)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
+    QMetaObject::activate(this, &staticMetaObject, 8, _a);
+}
+
+// SIGNAL 9
+void octave::octave_qscintilla::focus_console_after_command_signal()
+{
+    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
+}
+
+// SIGNAL 10
+void octave::octave_qscintilla::interpreter_event(const fcn_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 10, _a);
+}
+
+// SIGNAL 11
+void octave::octave_qscintilla::interpreter_event(const meth_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 11, _a);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
