@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/m-editor/octave-txt-lexer.h"
+#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/src/m-editor/octave-txt-lexer.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
