@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/dialog.h"
+#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/src/dialog.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__QUIWidgetCreator_t {
-    QByteArrayData data[25];
-    char stringdata0[309];
+    QByteArrayData data[42];
+    char stringdata0[499];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -47,27 +47,49 @@ QT_MOC_LITERAL(9, 121, 5), // "title"
 QT_MOC_LITERAL(10, 127, 8), // "filename"
 QT_MOC_LITERAL(11, 136, 7), // "dirname"
 QT_MOC_LITERAL(12, 144, 9), // "multimode"
-QT_MOC_LITERAL(13, 154, 21), // "dialog_button_clicked"
-QT_MOC_LITERAL(14, 176, 16), // "QAbstractButton*"
-QT_MOC_LITERAL(15, 193, 6), // "button"
-QT_MOC_LITERAL(16, 200, 20), // "list_select_finished"
-QT_MOC_LITERAL(17, 221, 8), // "selected"
-QT_MOC_LITERAL(18, 230, 14), // "button_pressed"
-QT_MOC_LITERAL(19, 245, 14), // "input_finished"
-QT_MOC_LITERAL(20, 260, 5), // "input"
-QT_MOC_LITERAL(21, 266, 19), // "filedialog_finished"
-QT_MOC_LITERAL(22, 286, 5), // "files"
-QT_MOC_LITERAL(23, 292, 4), // "path"
-QT_MOC_LITERAL(24, 297, 11) // "filterindex"
+QT_MOC_LITERAL(13, 154, 20), // "handle_create_dialog"
+QT_MOC_LITERAL(14, 175, 7), // "message"
+QT_MOC_LITERAL(15, 183, 4), // "icon"
+QT_MOC_LITERAL(16, 188, 6), // "button"
+QT_MOC_LITERAL(17, 195, 9), // "defbutton"
+QT_MOC_LITERAL(18, 205, 4), // "role"
+QT_MOC_LITERAL(19, 210, 21), // "dialog_button_clicked"
+QT_MOC_LITERAL(20, 232, 16), // "QAbstractButton*"
+QT_MOC_LITERAL(21, 249, 22), // "handle_create_listview"
+QT_MOC_LITERAL(22, 272, 4), // "list"
+QT_MOC_LITERAL(23, 277, 4), // "mode"
+QT_MOC_LITERAL(24, 282, 5), // "width"
+QT_MOC_LITERAL(25, 288, 6), // "height"
+QT_MOC_LITERAL(26, 295, 7), // "initial"
+QT_MOC_LITERAL(27, 303, 4), // "name"
+QT_MOC_LITERAL(28, 308, 6), // "prompt"
+QT_MOC_LITERAL(29, 315, 9), // "ok_string"
+QT_MOC_LITERAL(30, 325, 13), // "cancel_string"
+QT_MOC_LITERAL(31, 339, 20), // "list_select_finished"
+QT_MOC_LITERAL(32, 360, 8), // "selected"
+QT_MOC_LITERAL(33, 369, 14), // "button_pressed"
+QT_MOC_LITERAL(34, 384, 25), // "handle_create_inputlayout"
+QT_MOC_LITERAL(35, 410, 14), // "input_finished"
+QT_MOC_LITERAL(36, 425, 5), // "input"
+QT_MOC_LITERAL(37, 431, 24), // "handle_create_filedialog"
+QT_MOC_LITERAL(38, 456, 19), // "filedialog_finished"
+QT_MOC_LITERAL(39, 476, 5), // "files"
+QT_MOC_LITERAL(40, 482, 4), // "path"
+QT_MOC_LITERAL(41, 487, 11) // "filterindex"
 
     },
     "octave::QUIWidgetCreator\0create_dialog\0"
     "\0create_listview\0QIntList\0create_inputlayout\0"
     "QFloatList\0create_filedialog\0filters\0"
     "title\0filename\0dirname\0multimode\0"
-    "dialog_button_clicked\0QAbstractButton*\0"
-    "button\0list_select_finished\0selected\0"
-    "button_pressed\0input_finished\0input\0"
+    "handle_create_dialog\0message\0icon\0"
+    "button\0defbutton\0role\0dialog_button_clicked\0"
+    "QAbstractButton*\0handle_create_listview\0"
+    "list\0mode\0width\0height\0initial\0name\0"
+    "prompt\0ok_string\0cancel_string\0"
+    "list_select_finished\0selected\0"
+    "button_pressed\0handle_create_inputlayout\0"
+    "input_finished\0input\0handle_create_filedialog\0"
     "filedialog_finished\0files\0path\0"
     "filterindex"
 };
@@ -79,7 +101,7 @@ static const uint qt_meta_data_octave__QUIWidgetCreator[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       8,   14, // methods
+      12,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -87,16 +109,20 @@ static const uint qt_meta_data_octave__QUIWidgetCreator[] = {
        4,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    6,   54,    2, 0x06 /* Public */,
-       3,    9,   67,    2, 0x06 /* Public */,
-       5,    5,   86,    2, 0x06 /* Public */,
-       7,    5,   97,    2, 0x06 /* Public */,
+       1,    6,   74,    2, 0x06 /* Public */,
+       3,    9,   87,    2, 0x06 /* Public */,
+       5,    5,  106,    2, 0x06 /* Public */,
+       7,    5,  117,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-      13,    1,  108,    2, 0x0a /* Public */,
-      16,    2,  111,    2, 0x0a /* Public */,
-      19,    2,  116,    2, 0x0a /* Public */,
-      21,    3,  121,    2, 0x0a /* Public */,
+      13,    6,  128,    2, 0x0a /* Public */,
+      19,    1,  141,    2, 0x0a /* Public */,
+      21,    9,  144,    2, 0x0a /* Public */,
+      31,    2,  163,    2, 0x0a /* Public */,
+      34,    5,  168,    2, 0x0a /* Public */,
+      35,    2,  179,    2, 0x0a /* Public */,
+      37,    5,  184,    2, 0x0a /* Public */,
+      38,    3,  195,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QStringList,    2,    2,    2,    2,    2,    2,
@@ -105,10 +131,14 @@ static const uint qt_meta_data_octave__QUIWidgetCreator[] = {
     QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    8,    9,   10,   11,   12,
 
  // slots: parameters
-    QMetaType::Void, 0x80000000 | 14,   15,
-    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,   17,   18,
-    QMetaType::Void, QMetaType::QStringList, QMetaType::Int,   20,   18,
-    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int,   22,   23,   24,
+    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QStringList,   14,    9,   15,   16,   17,   18,
+    QMetaType::Void, 0x80000000 | 20,   16,
+    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int, QMetaType::Int, 0x80000000 | 4, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QString,   22,   23,   24,   25,   26,   27,   28,   29,   30,
+    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,   32,   33,
+    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, 0x80000000 | 6, 0x80000000 | 6, QMetaType::QStringList,    2,    2,    2,    2,    2,
+    QMetaType::Void, QMetaType::QStringList, QMetaType::Int,   36,   33,
+    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    8,    9,   10,   11,   12,
+    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int,   39,   40,   41,
 
        0        // eod
 };
@@ -123,10 +153,14 @@ void octave::QUIWidgetCreator::qt_static_metacall(QObject *_o, QMetaObject::Call
         case 1: _t->create_listview((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QIntList(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QStringList(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8])),(*reinterpret_cast< const QString(*)>(_a[9]))); break;
         case 2: _t->create_inputlayout((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QFloatList(*)>(_a[3])),(*reinterpret_cast< const QFloatList(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5]))); break;
         case 3: _t->create_filedialog((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
-        case 4: _t->dialog_button_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
-        case 5: _t->list_select_finished((*reinterpret_cast< const QIntList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 6: _t->input_finished((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
-        case 7: _t->filedialog_finished((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
+        case 4: _t->handle_create_dialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QStringList(*)>(_a[6]))); break;
+        case 5: _t->dialog_button_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
+        case 6: _t->handle_create_listview((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QIntList(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QStringList(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8])),(*reinterpret_cast< const QString(*)>(_a[9]))); break;
+        case 7: _t->list_select_finished((*reinterpret_cast< const QIntList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 8: _t->handle_create_inputlayout((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QFloatList(*)>(_a[3])),(*reinterpret_cast< const QFloatList(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5]))); break;
+        case 9: _t->input_finished((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
+        case 10: _t->handle_create_filedialog((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
+        case 11: _t->filedialog_finished((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -187,13 +221,13 @@ int octave::QUIWidgetCreator::qt_metacall(QMetaObject::Call _c, int _id, void **
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 8)
+        if (_id < 12)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 8;
+        _id -= 12;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 8)
+        if (_id < 12)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 8;
+        _id -= 12;
     }
     return _id;
 }
