@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/documentation.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/documentation.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -25,7 +25,7 @@ QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__documentation_browser_t {
     QByteArrayData data[11];
-    char stringdata0[137];
+    char stringdata0[140];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -40,16 +40,16 @@ QT_MOC_LITERAL(2, 51, 0), // ""
 QT_MOC_LITERAL(3, 52, 3), // "url"
 QT_MOC_LITERAL(4, 56, 7), // "keyword"
 QT_MOC_LITERAL(5, 64, 15), // "notice_settings"
-QT_MOC_LITERAL(6, 80, 16), // "const QSettings*"
-QT_MOC_LITERAL(7, 97, 8), // "settings"
-QT_MOC_LITERAL(8, 106, 7), // "zoom_in"
-QT_MOC_LITERAL(9, 114, 8), // "zoom_out"
-QT_MOC_LITERAL(10, 123, 13) // "zoom_original"
+QT_MOC_LITERAL(6, 80, 19), // "const gui_settings*"
+QT_MOC_LITERAL(7, 100, 8), // "settings"
+QT_MOC_LITERAL(8, 109, 7), // "zoom_in"
+QT_MOC_LITERAL(9, 117, 8), // "zoom_out"
+QT_MOC_LITERAL(10, 126, 13) // "zoom_original"
 
     },
     "octave::documentation_browser\0"
     "handle_index_clicked\0\0url\0keyword\0"
-    "notice_settings\0const QSettings*\0"
+    "notice_settings\0const gui_settings*\0"
     "settings\0zoom_in\0zoom_out\0zoom_original"
 };
 #undef QT_MOC_LITERAL
@@ -94,7 +94,7 @@ void octave::documentation_browser::qt_static_metacall(QObject *_o, QMetaObject:
         switch (_id) {
         case 0: _t->handle_index_clicked((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
         case 1: _t->handle_index_clicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
-        case 2: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
+        case 2: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
         case 3: _t->zoom_in(); break;
         case 4: _t->zoom_out(); break;
         case 5: _t->zoom_original(); break;
@@ -139,8 +139,8 @@ int octave::documentation_browser::qt_metacall(QMetaObject::Call _c, int _id, vo
     return _id;
 }
 struct qt_meta_stringdata_octave__documentation_t {
-    QByteArrayData data[33];
-    char stringdata0[477];
+    QByteArrayData data[34];
+    char stringdata0[481];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -153,45 +153,46 @@ QT_MOC_LITERAL(0, 0, 21), // "octave::documentation"
 QT_MOC_LITERAL(1, 22, 18), // "show_single_result"
 QT_MOC_LITERAL(2, 41, 0), // ""
 QT_MOC_LITERAL(3, 42, 15), // "notice_settings"
-QT_MOC_LITERAL(4, 58, 16), // "const QSettings*"
-QT_MOC_LITERAL(5, 75, 8), // "settings"
-QT_MOC_LITERAL(6, 84, 13), // "copyClipboard"
-QT_MOC_LITERAL(7, 98, 14), // "pasteClipboard"
-QT_MOC_LITERAL(8, 113, 9), // "selectAll"
-QT_MOC_LITERAL(9, 123, 8), // "load_ref"
-QT_MOC_LITERAL(10, 132, 4), // "name"
-QT_MOC_LITERAL(11, 137, 11), // "registerDoc"
-QT_MOC_LITERAL(12, 149, 13), // "unregisterDoc"
-QT_MOC_LITERAL(13, 163, 13), // "activate_find"
-QT_MOC_LITERAL(14, 177, 13), // "global_search"
-QT_MOC_LITERAL(15, 191, 21), // "global_search_started"
-QT_MOC_LITERAL(16, 213, 22), // "global_search_finished"
-QT_MOC_LITERAL(17, 236, 4), // "hits"
-QT_MOC_LITERAL(18, 241, 13), // "filter_update"
-QT_MOC_LITERAL(19, 255, 10), // "expression"
-QT_MOC_LITERAL(20, 266, 21), // "filter_update_history"
-QT_MOC_LITERAL(21, 288, 12), // "find_forward"
-QT_MOC_LITERAL(22, 301, 13), // "find_backward"
-QT_MOC_LITERAL(23, 315, 24), // "find_forward_from_anchor"
-QT_MOC_LITERAL(24, 340, 4), // "text"
-QT_MOC_LITERAL(25, 345, 22), // "record_anchor_position"
-QT_MOC_LITERAL(26, 368, 29), // "handle_cursor_position_change"
-QT_MOC_LITERAL(27, 398, 28), // "handle_search_result_clicked"
-QT_MOC_LITERAL(28, 427, 3), // "url"
-QT_MOC_LITERAL(29, 431, 20), // "update_history_menus"
-QT_MOC_LITERAL(30, 452, 13), // "open_hist_url"
-QT_MOC_LITERAL(31, 466, 8), // "QAction*"
-QT_MOC_LITERAL(32, 475, 1) // "a"
+QT_MOC_LITERAL(4, 58, 19), // "const gui_settings*"
+QT_MOC_LITERAL(5, 78, 8), // "settings"
+QT_MOC_LITERAL(6, 87, 13), // "copyClipboard"
+QT_MOC_LITERAL(7, 101, 14), // "pasteClipboard"
+QT_MOC_LITERAL(8, 116, 9), // "selectAll"
+QT_MOC_LITERAL(9, 126, 8), // "load_ref"
+QT_MOC_LITERAL(10, 135, 4), // "name"
+QT_MOC_LITERAL(11, 140, 11), // "registerDoc"
+QT_MOC_LITERAL(12, 152, 13), // "unregisterDoc"
+QT_MOC_LITERAL(13, 166, 13), // "activate_find"
+QT_MOC_LITERAL(14, 180, 13), // "global_search"
+QT_MOC_LITERAL(15, 194, 21), // "global_search_started"
+QT_MOC_LITERAL(16, 216, 22), // "global_search_finished"
+QT_MOC_LITERAL(17, 239, 4), // "hits"
+QT_MOC_LITERAL(18, 244, 13), // "filter_update"
+QT_MOC_LITERAL(19, 258, 10), // "expression"
+QT_MOC_LITERAL(20, 269, 21), // "filter_update_history"
+QT_MOC_LITERAL(21, 291, 4), // "find"
+QT_MOC_LITERAL(22, 296, 8), // "backward"
+QT_MOC_LITERAL(23, 305, 13), // "find_backward"
+QT_MOC_LITERAL(24, 319, 24), // "find_forward_from_anchor"
+QT_MOC_LITERAL(25, 344, 4), // "text"
+QT_MOC_LITERAL(26, 349, 22), // "record_anchor_position"
+QT_MOC_LITERAL(27, 372, 29), // "handle_cursor_position_change"
+QT_MOC_LITERAL(28, 402, 28), // "handle_search_result_clicked"
+QT_MOC_LITERAL(29, 431, 3), // "url"
+QT_MOC_LITERAL(30, 435, 20), // "update_history_menus"
+QT_MOC_LITERAL(31, 456, 13), // "open_hist_url"
+QT_MOC_LITERAL(32, 470, 8), // "QAction*"
+QT_MOC_LITERAL(33, 479, 1) // "a"
 
     },
     "octave::documentation\0show_single_result\0"
-    "\0notice_settings\0const QSettings*\0"
+    "\0notice_settings\0const gui_settings*\0"
     "settings\0copyClipboard\0pasteClipboard\0"
     "selectAll\0load_ref\0name\0registerDoc\0"
     "unregisterDoc\0activate_find\0global_search\0"
     "global_search_started\0global_search_finished\0"
     "hits\0filter_update\0expression\0"
-    "filter_update_history\0find_forward\0"
+    "filter_update_history\0find\0backward\0"
     "find_backward\0find_forward_from_anchor\0"
     "text\0record_anchor_position\0"
     "handle_cursor_position_change\0"
@@ -207,7 +208,7 @@ static const uint qt_meta_data_octave__documentation[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      22,   14, // methods
+      23,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -215,30 +216,31 @@ static const uint qt_meta_data_octave__documentation[] = {
        1,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  124,    2, 0x06 /* Public */,
+       1,    1,  129,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       3,    1,  127,    2, 0x0a /* Public */,
-       6,    0,  130,    2, 0x0a /* Public */,
-       7,    0,  131,    2, 0x0a /* Public */,
-       8,    0,  132,    2, 0x0a /* Public */,
-       9,    1,  133,    2, 0x0a /* Public */,
-      11,    1,  136,    2, 0x0a /* Public */,
-      12,    1,  139,    2, 0x0a /* Public */,
-      13,    0,  142,    2, 0x08 /* Private */,
-      14,    0,  143,    2, 0x08 /* Private */,
-      15,    0,  144,    2, 0x08 /* Private */,
-      16,    1,  145,    2, 0x08 /* Private */,
-      18,    1,  148,    2, 0x08 /* Private */,
-      20,    0,  151,    2, 0x08 /* Private */,
-      21,    0,  152,    2, 0x08 /* Private */,
-      22,    0,  153,    2, 0x08 /* Private */,
-      23,    1,  154,    2, 0x08 /* Private */,
-      25,    0,  157,    2, 0x08 /* Private */,
-      26,    0,  158,    2, 0x08 /* Private */,
-      27,    1,  159,    2, 0x08 /* Private */,
-      29,    0,  162,    2, 0x08 /* Private */,
-      30,    1,  163,    2, 0x08 /* Private */,
+       3,    1,  132,    2, 0x0a /* Public */,
+       6,    0,  135,    2, 0x0a /* Public */,
+       7,    0,  136,    2, 0x0a /* Public */,
+       8,    0,  137,    2, 0x0a /* Public */,
+       9,    1,  138,    2, 0x0a /* Public */,
+      11,    1,  141,    2, 0x0a /* Public */,
+      12,    1,  144,    2, 0x0a /* Public */,
+      13,    0,  147,    2, 0x08 /* Private */,
+      14,    0,  148,    2, 0x08 /* Private */,
+      15,    0,  149,    2, 0x08 /* Private */,
+      16,    1,  150,    2, 0x08 /* Private */,
+      18,    1,  153,    2, 0x08 /* Private */,
+      20,    0,  156,    2, 0x08 /* Private */,
+      21,    1,  157,    2, 0x08 /* Private */,
+      21,    0,  160,    2, 0x28 /* Private | MethodCloned */,
+      23,    0,  161,    2, 0x08 /* Private */,
+      24,    1,  162,    2, 0x08 /* Private */,
+      26,    0,  165,    2, 0x08 /* Private */,
+      27,    0,  166,    2, 0x08 /* Private */,
+      28,    1,  167,    2, 0x08 /* Private */,
+      30,    0,  170,    2, 0x08 /* Private */,
+      31,    1,  171,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QUrl,    2,
@@ -257,14 +259,15 @@ static const uint qt_meta_data_octave__documentation[] = {
     QMetaType::Void, QMetaType::Int,   17,
     QMetaType::Void, QMetaType::QString,   19,
     QMetaType::Void,
+    QMetaType::Void, QMetaType::Bool,   22,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QString,   24,
+    QMetaType::Void, QMetaType::QString,   25,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::QUrl,   28,
+    QMetaType::Void, QMetaType::QUrl,   29,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 31,   32,
+    QMetaType::Void, 0x80000000 | 32,   33,
 
        0        // eod
 };
@@ -276,7 +279,7 @@ void octave::documentation::qt_static_metacall(QObject *_o, QMetaObject::Call _c
         Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->show_single_result((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
-        case 1: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
+        case 1: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
         case 2: _t->copyClipboard(); break;
         case 3: _t->pasteClipboard(); break;
         case 4: _t->selectAll(); break;
@@ -289,14 +292,15 @@ void octave::documentation::qt_static_metacall(QObject *_o, QMetaObject::Call _c
         case 11: _t->global_search_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
         case 12: _t->filter_update((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 13: _t->filter_update_history(); break;
-        case 14: _t->find_forward(); break;
-        case 15: _t->find_backward(); break;
-        case 16: _t->find_forward_from_anchor((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 17: _t->record_anchor_position(); break;
-        case 18: _t->handle_cursor_position_change(); break;
-        case 19: _t->handle_search_result_clicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
-        case 20: _t->update_history_menus(); break;
-        case 21: _t->open_hist_url((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
+        case 14: _t->find((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 15: _t->find(); break;
+        case 16: _t->find_backward(); break;
+        case 17: _t->find_forward_from_anchor((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 18: _t->record_anchor_position(); break;
+        case 19: _t->handle_cursor_position_change(); break;
+        case 20: _t->handle_search_result_clicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
+        case 21: _t->update_history_menus(); break;
+        case 22: _t->open_hist_url((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -336,13 +340,13 @@ int octave::documentation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 22)
+        if (_id < 23)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 22;
+        _id -= 23;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 22)
+        if (_id < 23)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 22;
+        _id -= 23;
     }
     return _id;
 }
