@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/history-dock-widget.h"
+#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/src/history-dock-widget.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__history_dock_widget_t {
-    QByteArrayData data[31];
-    char stringdata0[451];
+    QByteArrayData data[33];
+    char stringdata0[487];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -48,23 +48,25 @@ QT_MOC_LITERAL(10, 128, 14), // "append_history"
 QT_MOC_LITERAL(11, 143, 10), // "hist_entry"
 QT_MOC_LITERAL(12, 154, 13), // "clear_history"
 QT_MOC_LITERAL(13, 168, 13), // "save_settings"
-QT_MOC_LITERAL(14, 182, 21), // "update_filter_history"
-QT_MOC_LITERAL(15, 204, 15), // "filter_activate"
-QT_MOC_LITERAL(16, 220, 6), // "enable"
-QT_MOC_LITERAL(17, 227, 7), // "ctxMenu"
-QT_MOC_LITERAL(18, 235, 3), // "pos"
-QT_MOC_LITERAL(19, 239, 19), // "handle_double_click"
-QT_MOC_LITERAL(20, 259, 10), // "modelIndex"
-QT_MOC_LITERAL(21, 270, 23), // "handle_contextmenu_copy"
-QT_MOC_LITERAL(22, 294, 4), // "flag"
-QT_MOC_LITERAL(23, 299, 27), // "handle_contextmenu_evaluate"
-QT_MOC_LITERAL(24, 327, 32), // "handle_contextmenu_create_script"
-QT_MOC_LITERAL(25, 360, 25), // "handle_contextmenu_filter"
-QT_MOC_LITERAL(26, 386, 13), // "copyClipboard"
-QT_MOC_LITERAL(27, 400, 14), // "pasteClipboard"
-QT_MOC_LITERAL(28, 415, 9), // "selectAll"
-QT_MOC_LITERAL(29, 425, 17), // "handle_visibility"
-QT_MOC_LITERAL(30, 443, 7) // "visible"
+QT_MOC_LITERAL(14, 182, 15), // "notice_settings"
+QT_MOC_LITERAL(15, 198, 19), // "const gui_settings*"
+QT_MOC_LITERAL(16, 218, 21), // "update_filter_history"
+QT_MOC_LITERAL(17, 240, 15), // "filter_activate"
+QT_MOC_LITERAL(18, 256, 6), // "enable"
+QT_MOC_LITERAL(19, 263, 7), // "ctxMenu"
+QT_MOC_LITERAL(20, 271, 3), // "pos"
+QT_MOC_LITERAL(21, 275, 19), // "handle_double_click"
+QT_MOC_LITERAL(22, 295, 10), // "modelIndex"
+QT_MOC_LITERAL(23, 306, 23), // "handle_contextmenu_copy"
+QT_MOC_LITERAL(24, 330, 4), // "flag"
+QT_MOC_LITERAL(25, 335, 27), // "handle_contextmenu_evaluate"
+QT_MOC_LITERAL(26, 363, 32), // "handle_contextmenu_create_script"
+QT_MOC_LITERAL(27, 396, 25), // "handle_contextmenu_filter"
+QT_MOC_LITERAL(28, 422, 13), // "copyClipboard"
+QT_MOC_LITERAL(29, 436, 14), // "pasteClipboard"
+QT_MOC_LITERAL(30, 451, 9), // "selectAll"
+QT_MOC_LITERAL(31, 461, 17), // "handle_visibility"
+QT_MOC_LITERAL(32, 479, 7) // "visible"
 
     },
     "octave::history_dock_widget\0information\0"
@@ -72,6 +74,7 @@ QT_MOC_LITERAL(30, 443, 7) // "visible"
     "command_create_script\0commands\0"
     "set_history\0hist\0append_history\0"
     "hist_entry\0clear_history\0save_settings\0"
+    "notice_settings\0const gui_settings*\0"
     "update_filter_history\0filter_activate\0"
     "enable\0ctxMenu\0pos\0handle_double_click\0"
     "modelIndex\0handle_contextmenu_copy\0"
@@ -89,7 +92,7 @@ static const uint qt_meta_data_octave__history_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      19,   14, // methods
+      20,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -97,27 +100,28 @@ static const uint qt_meta_data_octave__history_dock_widget[] = {
        3,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  109,    2, 0x06 /* Public */,
-       4,    1,  112,    2, 0x06 /* Public */,
-       6,    1,  115,    2, 0x06 /* Public */,
+       1,    1,  114,    2, 0x06 /* Public */,
+       4,    1,  117,    2, 0x06 /* Public */,
+       6,    1,  120,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       8,    1,  118,    2, 0x0a /* Public */,
-      10,    1,  121,    2, 0x0a /* Public */,
-      12,    0,  124,    2, 0x0a /* Public */,
-      13,    0,  125,    2, 0x0a /* Public */,
-      14,    0,  126,    2, 0x08 /* Private */,
-      15,    1,  127,    2, 0x08 /* Private */,
-      17,    1,  130,    2, 0x08 /* Private */,
-      19,    1,  133,    2, 0x08 /* Private */,
-      21,    1,  136,    2, 0x08 /* Private */,
-      23,    1,  139,    2, 0x08 /* Private */,
-      24,    1,  142,    2, 0x08 /* Private */,
-      25,    0,  145,    2, 0x08 /* Private */,
-      26,    0,  146,    2, 0x08 /* Private */,
-      27,    0,  147,    2, 0x08 /* Private */,
-      28,    0,  148,    2, 0x08 /* Private */,
-      29,    1,  149,    2, 0x08 /* Private */,
+       8,    1,  123,    2, 0x0a /* Public */,
+      10,    1,  126,    2, 0x0a /* Public */,
+      12,    0,  129,    2, 0x0a /* Public */,
+      13,    0,  130,    2, 0x0a /* Public */,
+      14,    1,  131,    2, 0x0a /* Public */,
+      16,    0,  134,    2, 0x08 /* Private */,
+      17,    1,  135,    2, 0x08 /* Private */,
+      19,    1,  138,    2, 0x08 /* Private */,
+      21,    1,  141,    2, 0x08 /* Private */,
+      23,    1,  144,    2, 0x08 /* Private */,
+      25,    1,  147,    2, 0x08 /* Private */,
+      26,    1,  150,    2, 0x08 /* Private */,
+      27,    0,  153,    2, 0x08 /* Private */,
+      28,    0,  154,    2, 0x08 /* Private */,
+      29,    0,  155,    2, 0x08 /* Private */,
+      30,    0,  156,    2, 0x08 /* Private */,
+      31,    1,  157,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::QString,    3,
@@ -129,18 +133,19 @@ static const uint qt_meta_data_octave__history_dock_widget[] = {
     QMetaType::Void, QMetaType::QString,   11,
     QMetaType::Void,
     QMetaType::Void,
+    QMetaType::Void, 0x80000000 | 15,    2,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   16,
-    QMetaType::Void, QMetaType::QPoint,   18,
-    QMetaType::Void, QMetaType::QModelIndex,   20,
-    QMetaType::Void, QMetaType::Bool,   22,
-    QMetaType::Void, QMetaType::Bool,   22,
-    QMetaType::Void, QMetaType::Bool,   22,
+    QMetaType::Void, QMetaType::Bool,   18,
+    QMetaType::Void, QMetaType::QPoint,   20,
+    QMetaType::Void, QMetaType::QModelIndex,   22,
+    QMetaType::Void, QMetaType::Bool,   24,
+    QMetaType::Void, QMetaType::Bool,   24,
+    QMetaType::Void, QMetaType::Bool,   24,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   30,
+    QMetaType::Void, QMetaType::Bool,   32,
 
        0        // eod
 };
@@ -158,18 +163,19 @@ void octave::history_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::C
         case 4: _t->append_history((*reinterpret_cast< const QString(*)>(_a[1]))); break;
         case 5: _t->clear_history(); break;
         case 6: _t->save_settings(); break;
-        case 7: _t->update_filter_history(); break;
-        case 8: _t->filter_activate((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 9: _t->ctxMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
-        case 10: _t->handle_double_click((*reinterpret_cast< QModelIndex(*)>(_a[1]))); break;
-        case 11: _t->handle_contextmenu_copy((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 12: _t->handle_contextmenu_evaluate((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 13: _t->handle_contextmenu_create_script((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 14: _t->handle_contextmenu_filter(); break;
-        case 15: _t->copyClipboard(); break;
-        case 16: _t->pasteClipboard(); break;
-        case 17: _t->selectAll(); break;
-        case 18: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 7: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 8: _t->update_filter_history(); break;
+        case 9: _t->filter_activate((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 10: _t->ctxMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
+        case 11: _t->handle_double_click((*reinterpret_cast< QModelIndex(*)>(_a[1]))); break;
+        case 12: _t->handle_contextmenu_copy((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 13: _t->handle_contextmenu_evaluate((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 14: _t->handle_contextmenu_create_script((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 15: _t->handle_contextmenu_filter(); break;
+        case 16: _t->copyClipboard(); break;
+        case 17: _t->pasteClipboard(); break;
+        case 18: _t->selectAll(); break;
+        case 19: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -223,13 +229,13 @@ int octave::history_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 19)
+        if (_id < 20)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 19;
+        _id -= 20;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 19)
+        if (_id < 20)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 19;
+        _id -= 20;
     }
     return _id;
 }
