@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/octave-dock-widget.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/octave-dock-widget.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -127,8 +127,8 @@ int octave::label_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void *
     return _id;
 }
 struct qt_meta_stringdata_octave__octave_dock_widget_t {
-    QByteArrayData data[35];
-    char stringdata0[466];
+    QByteArrayData data[39];
+    char stringdata0[515];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -142,51 +142,56 @@ QT_MOC_LITERAL(1, 27, 14), // "active_changed"
 QT_MOC_LITERAL(2, 42, 0), // ""
 QT_MOC_LITERAL(3, 43, 6), // "active"
 QT_MOC_LITERAL(4, 50, 17), // "queue_make_window"
-QT_MOC_LITERAL(5, 68, 17), // "queue_make_widget"
-QT_MOC_LITERAL(6, 86, 17), // "request_queue_cmd"
-QT_MOC_LITERAL(7, 104, 11), // "octave_cmd*"
-QT_MOC_LITERAL(8, 116, 5), // "focus"
-QT_MOC_LITERAL(9, 122, 17), // "handle_visibility"
-QT_MOC_LITERAL(10, 140, 7), // "visible"
-QT_MOC_LITERAL(11, 148, 15), // "notice_settings"
-QT_MOC_LITERAL(12, 164, 16), // "const QSettings*"
-QT_MOC_LITERAL(13, 181, 15), // "handle_settings"
-QT_MOC_LITERAL(14, 197, 26), // "handle_active_dock_changed"
-QT_MOC_LITERAL(15, 224, 19), // "octave_dock_widget*"
-QT_MOC_LITERAL(16, 244, 8), // "main_win"
-QT_MOC_LITERAL(17, 253, 12), // "QMainWindow*"
-QT_MOC_LITERAL(18, 266, 13), // "save_settings"
-QT_MOC_LITERAL(19, 280, 9), // "moveEvent"
-QT_MOC_LITERAL(20, 290, 11), // "QMoveEvent*"
-QT_MOC_LITERAL(21, 302, 5), // "event"
-QT_MOC_LITERAL(22, 308, 11), // "resizeEvent"
-QT_MOC_LITERAL(23, 320, 13), // "QResizeEvent*"
-QT_MOC_LITERAL(24, 334, 11), // "make_window"
-QT_MOC_LITERAL(25, 346, 8), // "not_used"
-QT_MOC_LITERAL(26, 355, 11), // "make_widget"
-QT_MOC_LITERAL(27, 367, 12), // "default_dock"
-QT_MOC_LITERAL(28, 380, 25), // "handle_visibility_changed"
-QT_MOC_LITERAL(29, 406, 11), // "eventFilter"
-QT_MOC_LITERAL(30, 418, 3), // "obj"
-QT_MOC_LITERAL(31, 422, 7), // "QEvent*"
-QT_MOC_LITERAL(32, 430, 1), // "e"
-QT_MOC_LITERAL(33, 432, 17), // "change_visibility"
-QT_MOC_LITERAL(34, 450, 15) // "toplevel_change"
+QT_MOC_LITERAL(5, 68, 18), // "widget_was_dragged"
+QT_MOC_LITERAL(6, 87, 17), // "queue_make_widget"
+QT_MOC_LITERAL(7, 105, 17), // "interpreter_event"
+QT_MOC_LITERAL(8, 123, 12), // "fcn_callback"
+QT_MOC_LITERAL(9, 136, 3), // "fcn"
+QT_MOC_LITERAL(10, 140, 13), // "meth_callback"
+QT_MOC_LITERAL(11, 154, 4), // "meth"
+QT_MOC_LITERAL(12, 159, 8), // "activate"
+QT_MOC_LITERAL(13, 168, 17), // "handle_visibility"
+QT_MOC_LITERAL(14, 186, 7), // "visible"
+QT_MOC_LITERAL(15, 194, 15), // "notice_settings"
+QT_MOC_LITERAL(16, 210, 19), // "const gui_settings*"
+QT_MOC_LITERAL(17, 230, 15), // "handle_settings"
+QT_MOC_LITERAL(18, 246, 26), // "handle_active_dock_changed"
+QT_MOC_LITERAL(19, 273, 19), // "octave_dock_widget*"
+QT_MOC_LITERAL(20, 293, 8), // "main_win"
+QT_MOC_LITERAL(21, 302, 12), // "QMainWindow*"
+QT_MOC_LITERAL(22, 315, 13), // "save_settings"
+QT_MOC_LITERAL(23, 329, 9), // "moveEvent"
+QT_MOC_LITERAL(24, 339, 11), // "QMoveEvent*"
+QT_MOC_LITERAL(25, 351, 5), // "event"
+QT_MOC_LITERAL(26, 357, 11), // "resizeEvent"
+QT_MOC_LITERAL(27, 369, 13), // "QResizeEvent*"
+QT_MOC_LITERAL(28, 383, 11), // "make_window"
+QT_MOC_LITERAL(29, 395, 11), // "make_widget"
+QT_MOC_LITERAL(30, 407, 8), // "not_used"
+QT_MOC_LITERAL(31, 416, 12), // "default_dock"
+QT_MOC_LITERAL(32, 429, 15), // "toplevel_change"
+QT_MOC_LITERAL(33, 445, 25), // "handle_visibility_changed"
+QT_MOC_LITERAL(34, 471, 11), // "eventFilter"
+QT_MOC_LITERAL(35, 483, 3), // "obj"
+QT_MOC_LITERAL(36, 487, 7), // "QEvent*"
+QT_MOC_LITERAL(37, 495, 1), // "e"
+QT_MOC_LITERAL(38, 497, 17) // "change_visibility"
 
     },
     "octave::octave_dock_widget\0active_changed\0"
-    "\0active\0queue_make_window\0queue_make_widget\0"
-    "request_queue_cmd\0octave_cmd*\0focus\0"
-    "handle_visibility\0visible\0notice_settings\0"
-    "const QSettings*\0handle_settings\0"
-    "handle_active_dock_changed\0"
+    "\0active\0queue_make_window\0widget_was_dragged\0"
+    "queue_make_widget\0interpreter_event\0"
+    "fcn_callback\0fcn\0meth_callback\0meth\0"
+    "activate\0handle_visibility\0visible\0"
+    "notice_settings\0const gui_settings*\0"
+    "handle_settings\0handle_active_dock_changed\0"
     "octave_dock_widget*\0main_win\0QMainWindow*\0"
     "save_settings\0moveEvent\0QMoveEvent*\0"
     "event\0resizeEvent\0QResizeEvent*\0"
-    "make_window\0not_used\0make_widget\0"
-    "default_dock\0handle_visibility_changed\0"
-    "eventFilter\0obj\0QEvent*\0e\0change_visibility\0"
-    "toplevel_change"
+    "make_window\0make_widget\0not_used\0"
+    "default_dock\0toplevel_change\0"
+    "handle_visibility_changed\0eventFilter\0"
+    "obj\0QEvent*\0e\0change_visibility"
 };
 #undef QT_MOC_LITERAL
 
@@ -196,65 +201,67 @@ static const uint qt_meta_data_octave__octave_dock_widget[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-      23,   14, // methods
+      24,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
-       4,       // signalCount
+       5,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,  129,    2, 0x06 /* Public */,
-       4,    0,  132,    2, 0x06 /* Public */,
-       5,    0,  133,    2, 0x06 /* Public */,
-       6,    1,  134,    2, 0x06 /* Public */,
+       1,    1,  134,    2, 0x06 /* Public */,
+       4,    1,  137,    2, 0x06 /* Public */,
+       6,    0,  140,    2, 0x06 /* Public */,
+       7,    1,  141,    2, 0x06 /* Public */,
+       7,    1,  144,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       8,    0,  137,    2, 0x0a /* Public */,
-       9,    1,  138,    2, 0x0a /* Public */,
-      11,    1,  141,    2, 0x0a /* Public */,
-      13,    1,  144,    2, 0x0a /* Public */,
-      14,    2,  147,    2, 0x0a /* Public */,
-      16,    0,  152,    2, 0x0a /* Public */,
-      18,    0,  153,    2, 0x0a /* Public */,
-      19,    1,  154,    2, 0x0a /* Public */,
-      22,    1,  157,    2, 0x0a /* Public */,
-      24,    1,  160,    2, 0x0a /* Public */,
-      24,    0,  163,    2, 0x2a /* Public | MethodCloned */,
-      26,    1,  164,    2, 0x0a /* Public */,
-      26,    0,  167,    2, 0x2a /* Public | MethodCloned */,
-      27,    1,  168,    2, 0x0a /* Public */,
-      27,    0,  171,    2, 0x2a /* Public | MethodCloned */,
-      28,    1,  172,    2, 0x09 /* Protected */,
-      29,    2,  175,    2, 0x09 /* Protected */,
-      33,    1,  180,    2, 0x08 /* Private */,
-      34,    1,  183,    2, 0x08 /* Private */,
+      12,    0,  147,    2, 0x0a /* Public */,
+      13,    1,  148,    2, 0x0a /* Public */,
+      15,    1,  151,    2, 0x0a /* Public */,
+      17,    1,  154,    2, 0x0a /* Public */,
+      18,    2,  157,    2, 0x0a /* Public */,
+      20,    0,  162,    2, 0x0a /* Public */,
+      22,    0,  163,    2, 0x0a /* Public */,
+      23,    1,  164,    2, 0x0a /* Public */,
+      26,    1,  167,    2, 0x0a /* Public */,
+      28,    1,  170,    2, 0x0a /* Public */,
+      28,    0,  173,    2, 0x2a /* Public | MethodCloned */,
+      29,    1,  174,    2, 0x0a /* Public */,
+      29,    0,  177,    2, 0x2a /* Public | MethodCloned */,
+      31,    1,  178,    2, 0x0a /* Public */,
+      31,    0,  181,    2, 0x2a /* Public | MethodCloned */,
+      32,    1,  182,    2, 0x09 /* Protected */,
+      33,    1,  185,    2, 0x09 /* Protected */,
+      34,    2,  188,    2, 0x09 /* Protected */,
+      38,    1,  193,    2, 0x08 /* Private */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::Bool,    3,
+    QMetaType::Void, QMetaType::Bool,    5,
     QMetaType::Void,
-    QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 7,    2,
+    QMetaType::Void, 0x80000000 | 8,    9,
+    QMetaType::Void, 0x80000000 | 10,   11,
 
  // slots: parameters
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   10,
-    QMetaType::Void, 0x80000000 | 12,    2,
-    QMetaType::Void, 0x80000000 | 12,    2,
-    QMetaType::Void, 0x80000000 | 15, 0x80000000 | 15,    2,    2,
-    0x80000000 | 17,
+    QMetaType::Void, QMetaType::Bool,   14,
+    QMetaType::Void, 0x80000000 | 16,    2,
+    QMetaType::Void, 0x80000000 | 16,    2,
+    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 19,    2,    2,
+    0x80000000 | 21,
     QMetaType::Void,
-    QMetaType::Void, 0x80000000 | 20,   21,
-    QMetaType::Void, 0x80000000 | 23,   21,
-    QMetaType::Void, QMetaType::Bool,   25,
+    QMetaType::Void, 0x80000000 | 24,   25,
+    QMetaType::Void, 0x80000000 | 27,   25,
+    QMetaType::Void, QMetaType::Bool,    5,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   25,
+    QMetaType::Void, QMetaType::Bool,   30,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   25,
+    QMetaType::Void, QMetaType::Bool,   30,
     QMetaType::Void,
-    QMetaType::Void, QMetaType::Bool,   10,
-    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 31,   30,   32,
     QMetaType::Void, QMetaType::Bool,    2,
+    QMetaType::Void, QMetaType::Bool,   14,
+    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 36,   35,   37,
     QMetaType::Void, QMetaType::Bool,    2,
 
        0        // eod
@@ -267,43 +274,37 @@ void octave::octave_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Ca
         Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->active_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 1: _t->queue_make_window(); break;
+        case 1: _t->queue_make_window((*reinterpret_cast< bool(*)>(_a[1]))); break;
         case 2: _t->queue_make_widget(); break;
-        case 3: _t->request_queue_cmd((*reinterpret_cast< octave_cmd*(*)>(_a[1]))); break;
-        case 4: _t->focus(); break;
-        case 5: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 6: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 7: _t->handle_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
-        case 8: _t->handle_active_dock_changed((*reinterpret_cast< octave_dock_widget*(*)>(_a[1])),(*reinterpret_cast< octave_dock_widget*(*)>(_a[2]))); break;
-        case 9: { QMainWindow* _r = _t->main_win();
+        case 3: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
+        case 4: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
+        case 5: _t->activate(); break;
+        case 6: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 7: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 8: _t->handle_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
+        case 9: _t->handle_active_dock_changed((*reinterpret_cast< octave_dock_widget*(*)>(_a[1])),(*reinterpret_cast< octave_dock_widget*(*)>(_a[2]))); break;
+        case 10: { QMainWindow* _r = _t->main_win();
             if (_a[0]) *reinterpret_cast< QMainWindow**>(_a[0]) = std::move(_r); }  break;
-        case 10: _t->save_settings(); break;
-        case 11: _t->moveEvent((*reinterpret_cast< QMoveEvent*(*)>(_a[1]))); break;
-        case 12: _t->resizeEvent((*reinterpret_cast< QResizeEvent*(*)>(_a[1]))); break;
-        case 13: _t->make_window((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 14: _t->make_window(); break;
-        case 15: _t->make_widget((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 16: _t->make_widget(); break;
-        case 17: _t->default_dock((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 18: _t->default_dock(); break;
-        case 19: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 20: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
+        case 11: _t->save_settings(); break;
+        case 12: _t->moveEvent((*reinterpret_cast< QMoveEvent*(*)>(_a[1]))); break;
+        case 13: _t->resizeEvent((*reinterpret_cast< QResizeEvent*(*)>(_a[1]))); break;
+        case 14: _t->make_window((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 15: _t->make_window(); break;
+        case 16: _t->make_widget((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 17: _t->make_widget(); break;
+        case 18: _t->default_dock((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 19: _t->default_dock(); break;
+        case 20: _t->toplevel_change((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 21: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 22: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
             if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
-        case 21: _t->change_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
-        case 22: _t->toplevel_change((*reinterpret_cast< bool(*)>(_a[1]))); break;
+        case 23: _t->change_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
         default: ;
         }
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
         switch (_id) {
         default: *reinterpret_cast<int*>(_a[0]) = -1; break;
-        case 3:
-            switch (*reinterpret_cast<int*>(_a[1])) {
-            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
-            case 0:
-                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< octave_cmd* >(); break;
-            }
-            break;
-        case 8:
+        case 9:
             switch (*reinterpret_cast<int*>(_a[1])) {
             default: *reinterpret_cast<int*>(_a[0]) = -1; break;
             case 1:
@@ -322,7 +323,7 @@ void octave::octave_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Ca
             }
         }
         {
-            typedef void (octave_dock_widget::*_t)();
+            typedef void (octave_dock_widget::*_t)(bool );
             if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::queue_make_window)) {
                 *result = 1;
                 return;
@@ -336,12 +337,19 @@ void octave::octave_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Ca
             }
         }
         {
-            typedef void (octave_dock_widget::*_t)(octave_cmd * );
-            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::request_queue_cmd)) {
+            typedef void (octave_dock_widget::*_t)(const fcn_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::interpreter_event)) {
                 *result = 3;
                 return;
             }
         }
+        {
+            typedef void (octave_dock_widget::*_t)(const meth_callback & );
+            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::interpreter_event)) {
+                *result = 4;
+                return;
+            }
+        }
     }
 }
 
@@ -370,13 +378,13 @@ int octave::octave_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 23)
+        if (_id < 24)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 23;
+        _id -= 24;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 23)
+        if (_id < 24)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 23;
+        _id -= 24;
     }
     return _id;
 }
@@ -389,9 +397,10 @@ void octave::octave_dock_widget::active_changed(bool _t1)
 }
 
 // SIGNAL 1
-void octave::octave_dock_widget::queue_make_window()
+void octave::octave_dock_widget::queue_make_window(bool _t1)
 {
-    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 1, _a);
 }
 
 // SIGNAL 2
@@ -401,10 +410,17 @@ void octave::octave_dock_widget::queue_make_widget()
 }
 
 // SIGNAL 3
-void octave::octave_dock_widget::request_queue_cmd(octave_cmd * _t1)
+void octave::octave_dock_widget::interpreter_event(const fcn_callback & _t1)
 {
     void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
     QMetaObject::activate(this, &staticMetaObject, 3, _a);
 }
+
+// SIGNAL 4
+void octave::octave_dock_widget::interpreter_event(const meth_callback & _t1)
+{
+    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
+    QMetaObject::activate(this, &staticMetaObject, 4, _a);
+}
 QT_WARNING_POP
 QT_END_MOC_NAMESPACE
