@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/resource-manager.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/resource-manager.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__resource_manager_t {
-    QByteArrayData data[7];
-    char stringdata0[120];
+    QByteArrayData data[1];
+    char stringdata0[25];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -34,18 +34,10 @@ struct qt_meta_stringdata_octave__resource_manager_t {
     )
 static const qt_meta_stringdata_octave__resource_manager_t qt_meta_stringdata_octave__resource_manager = {
     {
-QT_MOC_LITERAL(0, 0, 24), // "octave::resource_manager"
-QT_MOC_LITERAL(1, 25, 16), // "cleanup_instance"
-QT_MOC_LITERAL(2, 42, 0), // ""
-QT_MOC_LITERAL(3, 43, 19), // "varedit_color_chars"
-QT_MOC_LITERAL(4, 63, 19), // "varedit_color_names"
-QT_MOC_LITERAL(5, 83, 22), // "varedit_default_colors"
-QT_MOC_LITERAL(6, 106, 13) // "QList<QColor>"
+QT_MOC_LITERAL(0, 0, 24) // "octave::resource_manager"
 
     },
-    "octave::resource_manager\0cleanup_instance\0"
-    "\0varedit_color_chars\0varedit_color_names\0"
-    "varedit_default_colors\0QList<QColor>"
+    "octave::resource_manager"
 };
 #undef QT_MOC_LITERAL
 
@@ -55,44 +47,22 @@ static const uint qt_meta_data_octave__resource_manager[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       4,   14, // methods
+       0,    0, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
        0,       // flags
        0,       // signalCount
 
- // slots: name, argc, parameters, tag, flags
-       1,    0,   34,    2, 0x0a /* Public */,
-       3,    0,   35,    2, 0x0a /* Public */,
-       4,    0,   36,    2, 0x0a /* Public */,
-       5,    0,   37,    2, 0x0a /* Public */,
-
- // slots: parameters
-    QMetaType::Void,
-    QMetaType::QString,
-    QMetaType::QStringList,
-    0x80000000 | 6,
-
        0        // eod
 };
 
 void octave::resource_manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
-    if (_c == QMetaObject::InvokeMetaMethod) {
-        resource_manager *_t = static_cast<resource_manager *>(_o);
-        Q_UNUSED(_t)
-        switch (_id) {
-        case 0: _t->cleanup_instance(); break;
-        case 1: { QString _r = _t->varedit_color_chars();
-            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
-        case 2: { QStringList _r = _t->varedit_color_names();
-            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
-        case 3: { QList<QColor> _r = _t->varedit_default_colors();
-            if (_a[0]) *reinterpret_cast< QList<QColor>*>(_a[0]) = std::move(_r); }  break;
-        default: ;
-        }
-    }
+    Q_UNUSED(_o);
+    Q_UNUSED(_id);
+    Q_UNUSED(_c);
+    Q_UNUSED(_a);
 }
 
 const QMetaObject octave::resource_manager::staticMetaObject = {
@@ -117,17 +87,6 @@ void *octave::resource_manager::qt_metacast(const char *_clname)
 int octave::resource_manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = QObject::qt_metacall(_c, _id, _a);
-    if (_id < 0)
-        return _id;
-    if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 4)
-            qt_static_metacall(this, _c, _id, _a);
-        _id -= 4;
-    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 4)
-            *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 4;
-    }
     return _id;
 }
 QT_WARNING_POP
