@@ -9,7 +9,7 @@
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.i686/src/octave-5.1.0/libgui/src/tab-bar.h"
+#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/tab-bar.h"
 #include <QtCore/qbytearray.h>
 #include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
@@ -24,8 +24,8 @@ QT_BEGIN_MOC_NAMESPACE
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 struct qt_meta_stringdata_octave__tab_bar_t {
-    QByteArrayData data[7];
-    char stringdata0[104];
+    QByteArrayData data[8];
+    char stringdata0[119];
 };
 #define QT_MOC_LITERAL(idx, ofs, len) \
     Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
@@ -40,12 +40,14 @@ QT_MOC_LITERAL(2, 41, 0), // ""
 QT_MOC_LITERAL(3, 42, 15), // "switch_left_tab"
 QT_MOC_LITERAL(4, 58, 16), // "switch_right_tab"
 QT_MOC_LITERAL(5, 75, 13), // "move_tab_left"
-QT_MOC_LITERAL(6, 89, 14) // "move_tab_right"
+QT_MOC_LITERAL(6, 89, 14), // "move_tab_right"
+QT_MOC_LITERAL(7, 104, 14) // "sort_tabs_alph"
 
     },
     "octave::tab_bar\0close_current_tab_signal\0"
     "\0switch_left_tab\0switch_right_tab\0"
-    "move_tab_left\0move_tab_right"
+    "move_tab_left\0move_tab_right\0"
+    "sort_tabs_alph"
 };
 #undef QT_MOC_LITERAL
 
@@ -55,7 +57,7 @@ static const uint qt_meta_data_octave__tab_bar[] = {
        7,       // revision
        0,       // classname
        0,    0, // classinfo
-       5,   14, // methods
+       6,   14, // methods
        0,    0, // properties
        0,    0, // enums/sets
        0,    0, // constructors
@@ -63,13 +65,14 @@ static const uint qt_meta_data_octave__tab_bar[] = {
        1,       // signalCount
 
  // signals: name, argc, parameters, tag, flags
-       1,    1,   39,    2, 0x06 /* Public */,
+       1,    1,   44,    2, 0x06 /* Public */,
 
  // slots: name, argc, parameters, tag, flags
-       3,    0,   42,    2, 0x0a /* Public */,
-       4,    0,   43,    2, 0x0a /* Public */,
-       5,    0,   44,    2, 0x0a /* Public */,
-       6,    0,   45,    2, 0x0a /* Public */,
+       3,    0,   47,    2, 0x0a /* Public */,
+       4,    0,   48,    2, 0x0a /* Public */,
+       5,    0,   49,    2, 0x0a /* Public */,
+       6,    0,   50,    2, 0x0a /* Public */,
+       7,    0,   51,    2, 0x0a /* Public */,
 
  // signals: parameters
     QMetaType::Void, QMetaType::Bool,    2,
@@ -78,6 +81,7 @@ static const uint qt_meta_data_octave__tab_bar[] = {
     QMetaType::Void,
     QMetaType::Void,
     QMetaType::Void,
+    QMetaType::Void,
     QMetaType::Void,
 
        0        // eod
@@ -94,6 +98,7 @@ void octave::tab_bar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int
         case 2: _t->switch_right_tab(); break;
         case 3: _t->move_tab_left(); break;
         case 4: _t->move_tab_right(); break;
+        case 5: _t->sort_tabs_alph(); break;
         default: ;
         }
     } else if (_c == QMetaObject::IndexOfMethod) {
@@ -133,13 +138,13 @@ int octave::tab_bar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 5)
+        if (_id < 6)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 5;
+        _id -= 6;
     } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 5)
+        if (_id < 6)
             *reinterpret_cast<int*>(_a[0]) = -1;
-        _id -= 5;
+        _id -= 6;
     }
     return _id;
 }
